@@ -18,7 +18,7 @@ NULL
 #'                           that \code{-} is not accepted.
 #' @param    numMutations    a whole number indicating the number of mutations to be 
 #'                           introduced into \code{sequence}, if \code{frequency=FALSE}.
-#'                           A fraction bewteen 0 and 1 indicating the mutation frequency
+#'                           A fraction between 0 and 1 indicating the mutation frequency
 #'                           if \code{frequency=TRUE}.
 #' @param    targetingModel  5-mer \link{TargetingModel} object to be used for computing 
 #'                           probabilities of mutations at each position. Defaults to
@@ -38,9 +38,10 @@ NULL
 #' Mutations are not introduced to positions in the input \code{sequence} that contain 
 #' \code{.} or \code{N}.
 #' 
-#' With \code{frequency=TRUE}, the number of mutations introduced is the \code{floor} of 
-#' the length of the sequence multiplied by the mutation frequency specified via
-#' \code{numMutations}.
+#' With \code{frequency=TRUE}, the number of mutations is calculated according to the probability
+#' of mutation at each position. For example, if \code{numMutations=0.05} and the length of 
+#' the input \code{sequence} is 100, then the number of mutations will be sampled from a 
+#' binomial distribution with 100 trials and a probability of 0.05.
 #' 
 #' @seealso  See \link{shmulateTree} for imposing mutations on a lineage tree. 
 #'           See \link{HH_S5F} and \link{MK_RS5NF} for predefined 
@@ -116,7 +117,8 @@ shmulateSeq <- function(sequence, numMutations, targetingModel=HH_S5F,
     # if specifying mutation frequency instead of count, 
     # get corresponding mutation count based on sequence length
     if (frequency) {
-        numMutations <- floor(sim_leng*numMutations)
+        sampleMutations <- rbinom(n=1, size=sim_leng, prob=numMutations)
+        numMutations <- sampleMutations
     }
     
     if (numMutations > sim_leng) {
